embassy-usb-host

Crates

git

Versions

default

Flavors

HIDDescriptor

Struct HIDDescriptor 

pub struct HIDDescriptor {
    pub bcd_hid: u16,
    pub country_code: u8,
    pub num_descriptors: u8,
    pub descriptor_type0: u8,
    pub descriptor_length0: u16,
}
USB HID class descriptor.

This descriptor identifies subordinate class descriptors. (USB HID 1.11 6.2.1)

Fields

bcd_hid: u16

USB HID specification version that the class descriptors comply to.

country_code: u8

Country code.

For country code 0, the hardware is not localized.

Keyboards may use this field to identify the language of the key caps.

num_descriptors: u8

Number of class descriptors.

descriptor_type0: u8

Type of the class descriptor 0.

descriptor_length0: u16

Length of the class descriptor 0.

Implementations

Source

impl HIDDescriptor

pub const SUPPORTED_DESCRIPTORS: u8 = 1

Maximum number of class descriptors that we support (at most 83).